---
image: https://assets.vercel.com/image/upload/v1630059453/swr/v1.png
description: 'Almost 2 years ago we open sourced SWR, the tiny data-fetching React library that people love. Today we are reaching another milestone: the 1.0 version of SWR.'
date: August 27th, 2021
---

IamAI v3.0
===========

hi